// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GCTEXT = GrapeCity.Documents.Text;
using GCDRAW = GrapeCity.Documents.Drawing;

namespace DsPdfWeb.Demos.Basics
{
    // 合字（単一のグリフ内に２つ以上の文字が結合されたもの）は、選択されたフォントがサポートし、
    // 対応するフォント機能がオンである場合に、DsPdf によってサポートされます。
    // フォント機能の完全なリストについては、https://www.microsoft.com/typography/otspec/featurelist.htm を参照してください。
    // また、FontFeatures も参照してください。
    public class Ligatures
    {
        public int CreatePDF(Stream stream)
        {
            // 一般的なラテン文字のリスト。
            const string latinLigatures = "fi, fj, fl, ff, ffi, ffl.";
            // 合字関連のフォント機能を設定します。
            // すべて ON:
            FontFeature[] allOn = new FontFeature[]
            {
                new FontFeature(FeatureTag.clig, true), //文脈上の合体
                new FontFeature(FeatureTag.dlig, true), //自由詞
                new FontFeature(FeatureTag.hlig, true), //歴史的合字
                new FontFeature(FeatureTag.liga, true), //標準的な連結子
                new FontFeature(FeatureTag.rlig, true), //必要な連結子
            };
            // すべて OFF:
            FontFeature[] allOff = new FontFeature[]
            {
                new FontFeature(FeatureTag.clig, false),
                new FontFeature(FeatureTag.dlig, false),
                new FontFeature(FeatureTag.hlig, false),
                new FontFeature(FeatureTag.liga, false),
                new FontFeature(FeatureTag.rlig, false),
            };
            var doc = new GcPdfDocument();
            var g = doc.NewPage().Graphics;
            // テキストの挿入位置。
            var ip = new PointF(72, 72);
            var tf = new TextFormat();
            tf.Font = GCTEXT.Font.FromFile(Path.Combine("Resources", "Fonts", "times.ttf"));
            tf.FontSize = 20;
            g.DrawString($"Common Latin ligatures, font {tf.Font.FontFamilyName}", tf, ip);
            ip.Y += 36;
            // すべての合字機能を OFF にします。
            tf.FontFeatures = allOff;
            g.DrawString($"All ligature features OFF: {latinLigatures}", tf, ip);
            ip.Y += 36;
            // すべての合字機能を ON にします。
            tf.FontFeatures = allOn;
            g.DrawString($"All ligature features ON: {latinLigatures}", tf, ip);
            ip.Y += 72;
            // 異なるフォントで繰り返します。
            tf.Font = GCTEXT.Font.FromFile(Path.Combine("Resources", "Fonts", "Gabriola.ttf"));
            g.DrawString($"Common Latin ligatures, font {tf.Font.FontFamilyName}", tf, ip);
            ip.Y += 36;
            // すべての合字機能を OFF にします。
            tf.FontFeatures = allOff;
            g.DrawString($"All ligature features OFF: {latinLigatures}", tf, ip);
            ip.Y += 36;
            // すべての合字機能を ON にします。
            tf.FontFeatures = allOn;
            g.DrawString($"All ligature features ON: {latinLigatures}", tf, ip);
            // PDF ドキュメントを保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
